@@ -7,7 +7,7 @@
 #pragma once
 
 #include <powerdevilaction.h>
-#include <powerdevilbackendinterface.h>
+#include <powerdevilkeyboardbrightnesslogic.h>
 
 namespace PowerDevil::BundledActions
 {
@@ -32,7 +32,7 @@ public:
     int keyboardBrightnessSteps() const;
 
 public Q_SLOTS:
-    void onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &brightnessInfo);
+    void onBrightnessChangedFromController(const KeyboardBrightnessLogic::BrightnessInfo &brightnessInfo);
 
     // DBus export
     void increaseKeyboardBrightness();
